{% extends "leprikon/base.html" %}
{% load i18n %}

{% block content %}

<h1>{% block title %}{% trans 'Password change successful' %}{% endblock %}</h1>

<p>{% trans 'Your password was changed.' %}</p>

{% endblock %}
