# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-11-26 09:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0019_independent_registrations'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='clubregistration',
            name='parents',
        ),
        migrations.RemoveField(
            model_name='clubregistration',
            name='participant',
        ),
        migrations.RemoveField(
            model_name='eventregistration',
            name='parents',
        ),
        migrations.RemoveField(
            model_name='eventregistration',
            name='participant',
        ),
    ]
